summaryrefslogtreecommitdiffstats
path: root/kstyles/kthemestyle/kstyledirs.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /kstyles/kthemestyle/kstyledirs.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kstyles/kthemestyle/kstyledirs.h')
-rw-r--r--kstyles/kthemestyle/kstyledirs.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kstyles/kthemestyle/kstyledirs.h b/kstyles/kthemestyle/kstyledirs.h
index b23457a07..9d2635136 100644
--- a/kstyles/kthemestyle/kstyledirs.h
+++ b/kstyles/kthemestyle/kstyledirs.h
@@ -23,8 +23,8 @@
#define KSTYLE_DIRS_H
-#include <qsettings.h>
-#include <qstringlist.h>
+#include <tqsettings.h>
+#include <tqstringlist.h>
#include <kstandarddirs.h>
/**
@@ -34,7 +34,7 @@
* @version $Id$
*
* This class provides a this wrapper for styles around KStandardDirs,
* permitting integration with QSettings and easy loading of pixmaps
*
* It add share/apps/kstyle/themes as "themerc",
* share/apps/kstyle/pixmaps "themepixmap"
@@ -59,13 +59,13 @@ public:
Adds all of KDE directories of type type to the seach path of q.
For example, when one does the following:
- QSettings settings;
+ TQSettings settings;
KStyleDirs dirs;
dirs.addToSearch("config",settings);
The one can do settings.readEntry("kstyle/KDE/WidgetStyle") to access a settings in kstylerc.
*/
- void addToSearch( const char* type, QSettings& q) const; //Better name?
+ void addToSearch( const char* type, TQSettings& q) const; //Better name?
protected:
static KStyleDirs* instance;
@@ -34,7 +34,7 @@
*
* This class provides a this wrapper for styles around KStandardDirs,
-* permitting integration with QSettings and easy loading of pixmaps
+* permitting integration with TQSettings and easy loading of pixmaps
*
* It add share/apps/kstyle/themes as "themerc",